"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const console_1 = __importDefault(require("console"));
const _3_0_3_1 = require("@fresha/openapi-model/build/3.0.3");
const yargs_1 = __importDefault(require("yargs"));
const helpers_1 = require("yargs/helpers");
const Differ_1 = require("./Differ");
try {
    const argv = (0, yargs_1.default)((0, helpers_1.hideBin)(process.argv))
        .epilog('For more information, see https://github.com/fresha/api-tools/tree/main/packages/openapi-diff')
        .usage('Usage: $0 [OPTIONS] FILE1 FILE2')
        .string('print-version')
        .describe('print-version', 'Prints suggested new version')
        .boolean('update-version')
        .describe('update-version', 'Updates schema version based on changes')
        .boolean('verbose')
        .alias('verbose', 'v')
        .describe('verbose', 'Print more information on console')
        .parseSync();
    const [inputPath1, inputPath2] = argv._;
    (0, assert_1.default)(typeof inputPath1 === 'string', `Required a filename`);
    (0, assert_1.default)(typeof inputPath2 === 'string', `Required a filename`);
    const reader = new _3_0_3_1.OpenAPIReader();
    const openapi1 = reader.parseFromFile(inputPath1);
    const openapi2 = reader.parseFromFile(inputPath2);
    const differ = new Differ_1.Differ(openapi1, openapi2);
    differ.calculate();
    if (argv.printVersion) {
        const suggestedNewVersion = differ.newVersion;
        console_1.default.log(suggestedNewVersion);
    }
    else if (argv.updateVersion) {
        openapi2.info.version = differ.newVersion;
        const writer = new _3_0_3_1.OpenAPIWriter();
        writer.writeToFile(openapi2, inputPath2);
    }
    else {
        differ.print();
        if (differ.outdatedVersion) {
            process.exit(1);
        }
    }
}
catch (err) {
    console_1.default.log(err);
    process.exit(1);
}
//# sourceMappingURL=index.js.map